//
//  NSObject+BGDataBinding.h
//  Epics
//
//  Created by Dominic Rodemer on 20/05/15.
//  Copyright (c) 2015 brandagram GmbH. All rights reserved.
//

#import <BGFoundation/BGFoundation.h>

// If this is set to 1 automatic cleanup of observers on object deallocation will be enabled.
// To achieve automatic cleanup, we swizzeld dealloc.
// If set to 0 observers must be cleaned up manually.
#ifndef BG_DATA_BINDING_AUTOCLEANUP
#define BG_DATA_BINDING_AUTOCLEANUP 1
#endif

extern NSString *const kBGDataBindingChangeObjectKey;
extern NSString *const kBGDataBindingChangeOldKey;
extern NSString *const kBGDataBindingChangeNewKey;
extern NSString *const kBGDataBindingChangeKeyPathKey;

typedef id (^BGDataBindingValueTransformation)(id value);

@interface NSObject (BGDataBinding)

- (void)bg_addTarget:(id)target action:(SEL)action forKeyPathChange:(NSString *)keyPath;
- (void)bg_addTarget:(id)target action:(SEL)action forKeyPathChange:(NSString *)keyPath callImmediately:(BOOL)callImmediately;
- (void)bg_addTarget:(id)target action:(SEL)action forKeyPathChanges:(NSArray *)keyPaths;
- (void)bg_addTarget:(id)target action:(SEL)action forKeyPathChanges:(NSArray *)keyPaths callImmediately:(BOOL)callImmediately;

- (void)bg_removeTarget:(id)target action:(SEL)action forKeyPathChange:(NSString *)keyPath;

- (void)bg_bindKey:(NSString *)key toKeyPath:(NSString *)foreignKeyPath ofObject:(id)object;
- (void)bg_bindKey:(NSString *)key toKeyPath:(NSString *)foreignKeyPath ofObject:(id)object withValueTransformation:(BGDataBindingValueTransformation)valueTransformation;

- (void)bg_unbindKey:(NSString *)key fromKeyPath:(NSString *)foreignKeyPath ofObject:(id)object;

#if !BG_DATA_BINDING_AUTOCLEANUP
- (void)bg_cleanupObservers;
#endif

@end
