//
//  BGFileMonitor.h
//  BGFoundation
//
//  Created by Dominic Rodemer on 23/12/15.
//  Copyright © 2015 brandagram GmbH. All rights reserved.
//

#import <Foundation/Foundation.h>

typedef NS_ENUM(NSUInteger, BGFileMonitorEvent) {
    BGFileMonitorEventDelete = DISPATCH_VNODE_DELETE,
    BGFileMonitorEventWrite = DISPATCH_VNODE_WRITE,
    BGFileMonitorEventExtend = DISPATCH_VNODE_EXTEND,
    BGFileMonitorEventAttrib = DISPATCH_VNODE_ATTRIB,
    BGFileMonitorEventLink = DISPATCH_VNODE_LINK,
    BGFileMonitorEventRename = DISPATCH_VNODE_RENAME,
    BGFileMonitorEventRevoke = DISPATCH_VNODE_REVOKE,
    BGFileMonitorEventUnlock = DISPATCH_VNODE_FUNLOCK
};

typedef void (^BGFileMonitorBlock) (void);

@interface BGFileMonitor : NSObject
{
    NSURL *fileURL;
    BOOL isDirectoryAtURL;
    
    BGFileMonitorEvent events;
    BGFileMonitorBlock block;
    NSTimer *timer;
    
    unsigned long long lastSize;
    int fileDescriptor;
    dispatch_queue_t queue;
    dispatch_source_t source;
}

@property (nonatomic, strong, readonly) NSURL *fileURL;
@property (nonatomic, readonly) BOOL isDirectoryAtURL;

@property (nonatomic, readonly) BGFileMonitorEvent events;
@property (nonatomic, copy, readonly) BGFileMonitorBlock block;

+ (BGFileMonitor *)fileMonitorForFileURL:(NSURL *)fileURL block:(BGFileMonitorBlock)block;
+ (BGFileMonitor *)fileMonitorForFileURL:(NSURL *)fileURL atEvents:(BGFileMonitorEvent)events block:(BGFileMonitorBlock)block;

- (void)startMonitoring;
- (void)stopMonitoring;

@end
