//
//  BGImageCache.h
//  BGFoundation
//
//  Created by Dominic Rodemer on 06.10.14.
//  Copyright (c) 2014 brandagram GmbH. All rights reserved.
//

#import <Foundation/Foundation.h>

#if !TARGET_OS_IPHONE
    #import <AppKit/AppKit.h>
    #ifndef UIImage
        #define UIImage NSImage
    #endif
#else
    #import <UIKit/UIKit.h>
#endif

typedef NS_ENUM(NSInteger, BGImageCacheType) {

    BGImageCacheTypeNone,
    BGImageCacheTypeDisk,
    BGImageCacheTypeMemory
};

typedef void(^BGImageCacheQueryCompletedBlock)(UIImage *image, BGImageCacheType cacheType);
typedef void(^BGImageCacheCheckCacheCompletionBlock)(BOOL isInCache);
typedef void(^BGImageCacheCalculateSizeBlock)(NSUInteger fileCount, NSUInteger totalSize);

UIImage *BGImageCacheScaledImageForKey(NSString *key, UIImage *image);


@interface BGImageCache : NSObject
{
    NSFileManager *fileManager;
    dispatch_queue_t queue;
    
    NSCache *memoryCache;
    NSString *diskCachePath;
    NSMutableArray *customPaths;
    
    NSInteger maxCacheAge;
}

@property (nonatomic) NSInteger maxCacheAge;
@property (nonatomic) NSUInteger maxMemoryCost;
@property (nonatomic) NSUInteger maxCacheSize;

+ (BGImageCache *)sharedImageCache;

- (id)initWithNamespace:(NSString *)name;

- (void)addReadOnlyCachePath:(NSString *)path;

- (void)storeImage:(UIImage *)image forKey:(NSString *)key;
- (void)storeImage:(UIImage *)image forKey:(NSString *)key toDisk:(BOOL)toDisk;
- (void)storeImage:(UIImage *)image recalculateFromImage:(BOOL)recalculate imageData:(NSData *)imageData forKey:(NSString *)key toDisk:(BOOL)toDisk;

- (NSOperation *)queryDiskCacheForKey:(NSString *)key done:(BGImageCacheQueryCompletedBlock)doneBlock;

- (UIImage *)imageFromMemoryCacheForKey:(NSString *)key;
- (UIImage *)imageFromDiskCacheForKey:(NSString *)key;

- (void)removeImageForKey:(NSString *)key;
- (void)removeImageForKey:(NSString *)key withCompletion:(void(^)(void))completion;
- (void)removeImageForKey:(NSString *)key fromDisk:(BOOL)fromDisk;
- (void)removeImageForKey:(NSString *)key fromDisk:(BOOL)fromDisk withCompletion:(void(^)(void))completion;

- (void)wipeMemoryCache;

- (void)wipeDiskCache;
- (void)wipeDiskCacheOnCompletion:(void(^)(void))completion;

- (void)removeExpiredImagesFromDisk;
- (void)removeExpiredImagesFromDiskWithCompletionBlock:(void(^)(void))completionBlock;

- (NSUInteger)getSize;
- (NSUInteger)getDiskCount;

- (void)calculateSizeWithCompletionBlock:(BGImageCacheCalculateSizeBlock)completionBlock;

- (BOOL)diskImageExistsWithKey:(NSString *)key;
- (void)diskImageExistsWithKey:(NSString *)key completion:(BGImageCacheCheckCacheCompletionBlock)completionBlock;

- (NSString *)cachePathForKey:(NSString *)key inPath:(NSString *)path;
- (NSString *)defaultCachePathForKey:(NSString *)key;

@end
