//
//  BGInputValidator.h
//  BGFoundation
//
//  Created by Dominic Rodemer on 26.01.14.
//  Copyright (c) 2014 brandagram GmbH. All rights reserved.
//

#import <Foundation/Foundation.h>

#if (TARGET_OS_EMBEDDED || TARGET_OS_IPHONE)
#import <UIKit/UIKit.h>
#else
#import <Cocoa/Cocoa.h>
#endif

typedef NS_ENUM(NSInteger, BGInputValidatorState) {
    BGInputValidatorStateUnknown = 0,
    BGInputValidatorStatePassed,
    BGInputValidatorStateFailed
    
};


@protocol BGInputValidatorSubclassingHooks <NSObject>

- (void)validate;

@end


@interface BGInputValidator : NSObject <BGInputValidatorSubclassingHooks>
{
    id input;
    BGInputValidatorState validationState;
    
    NSString *validationFailedMessage;
    NSString *validationPassedMessage;
    
#if (TARGET_OS_EMBEDDED || TARGET_OS_IPHONE)
    UIImage *validationFailedImage;
    UIImage *validationPassedImage;
#else
    NSImage *validationFailedImage;
    NSImage *validationPassedImage;
#endif
    
    
    BOOL emtpyInputShouldPassValidation;
}

@property (nonatomic, strong) id input;
@property (nonatomic, readonly) BGInputValidatorState validationState;

@property (nonatomic, strong) NSString *validationFailedMessage;
@property (nonatomic, strong) NSString *validationPassedMessage;
#if (TARGET_OS_EMBEDDED || TARGET_OS_IPHONE)
@property (nonatomic, strong) UIImage *validationFailedImage;
@property (nonatomic, strong) UIImage *validationPassedImage;
#else
@property (nonatomic, strong) NSImage *validationFailedImage;
@property (nonatomic, strong) NSImage *validationPassedImage;
#endif

@property (nonatomic, assign) BOOL emtpyInputShouldPassValidation;

+ (instancetype)validator;
+ (instancetype)validatorWithFailMessage:(NSString *)validationFailedMessage;
#if (TARGET_OS_EMBEDDED || TARGET_OS_IPHONE)
+ (instancetype)validatorWithFailMessage:(NSString *)validationFailedMessage failImage:(UIImage *)validationFailedImage;
#else
+ (instancetype)validatorWithFailMessage:(NSString *)validationFailedMessage failImage:(NSImage *)validationFailedImage;
#endif

- (NSString *)inputValueForInput:(id)anInput;
- (NSString *)inputValue;

@end
