//
//  BGLogging.h
//  BGFoundation
//
//  Created by Dominic Rodemer on 06/01/16.
//  Copyright © 2016 brandgram GmbH. All rights reserved.
//

#ifndef BGLogging_h
#define BGLogging_h

#ifdef DEBUG
    #define BGErrorLog(_error_) if (_error_) { NSLog(@"%@ (%d) ERROR: %@", [[NSString stringWithUTF8String:__FILE__] lastPathComponent], \
                                                                           __LINE__, \
                                                                           [_error_ localizedDescription]); }
    #define BGCFErrorLog(_error_) if (_error_) { CFShow(_error_); }
#else
    #define BGErrorLog(_error_)
    #define BGCFErrorLog(_error_)
#endif


#ifdef DEBUG
#define BGLog(x, ...) NSLog(@"%s %d: " x, __FUNCTION__, __LINE__, ##__VA_ARGS__)
#else
#define BGLog(x, ...)
#endif


#ifdef DEBUG
#define BGAssertLog(...) [[NSAssertionHandler currentHandler] handleFailureInFunction:[NSString stringWithCString: __PRETTY_FUNCTION__ encoding:NSUTF8StringEncoding] \
                                                                                 file:[NSString stringWithCString:__FILE__ encoding:NSUTF8StringEncoding] \
                                                                           lineNumber:__LINE__ \
                                                                          description:__VA_ARGS__]
#else
    #ifndef NS_BLOCK_ASSERTIONS
        #define NS_BLOCK_ASSERTIONS
    #endif
    #define BGAssertLog(...) NSLog(@"%s %@", __FUNCTION__, [NSString stringWithFormat:__VA_ARGS__])
#endif

#define BGAssert(_condition_, ...) do { if (!(_condition_)) { BGAssertLog(__VA_ARGS__); }} while(0)

#endif /* BGLogging_h */
