//
//  BGRate.h
//  BGFoundation
//
//  Created by Dominic Rodemer on 12.12.18.
//  Copyright © 2018 brandgram GmbH. All rights reserved.
//

#import <Foundation/Foundation.h>

#import <TargetConditionals.h>
#if TARGET_OS_IPHONE
#import <UIKit/UIKit.h>
#import <StoreKit/StoreKit.h>
#else
#import <Cocoa/Cocoa.h>
#endif

extern NSUInteger const BGRateAppStoreGameGenreID;
extern NSString *const BGRateErrorDomain;

extern NSString *const BGRateCouldNotConnectToAppStoreNotification;
extern NSString *const BGRateDidDetectAppUpdateNotification;
extern NSString *const BGRateDidPromptForRatingNotification;
extern NSString *const BGRateUserDidAttemptToRateAppNotification;
extern NSString *const BGRateUserDidDeclineToRateAppNotification;
extern NSString *const BGRateUserDidRequestReminderToRateAppNotification;
extern NSString *const BGRateDidOpenAppStoreNotification;

typedef NS_ENUM(NSUInteger, BGRateErrorCode) {
    BGRateErrorBundleIdDoesNotMatchAppStore = 1,
    BGRateErrorApplicationNotFoundOnAppStore,
    BGRateErrorApplicationIsNotLatestVersion,
    BGRateErrorCouldNotOpenRatingPageURL
};


@protocol BGRateDelegate;

@interface BGRate : NSObject
{
    
}

@property (nonatomic, weak) id<BGRateDelegate> delegate;

@property (nonatomic, assign) NSUInteger appStoreID;

@property (nonatomic, assign) NSUInteger appStoreGenreID;
@property (nonatomic, copy) NSString *appStoreCountry;
@property (nonatomic, copy) NSString *applicationName;
@property (nonatomic, copy) NSString *applicationVersion;
@property (nonatomic, copy) NSString *applicationBundleID;

@property (nonatomic, assign) NSUInteger usesUntilPrompt;
@property (nonatomic, assign) NSUInteger eventsUntilPrompt;
@property (nonatomic, assign) float daysUntilPrompt;
@property (nonatomic, assign) float usesPerWeekForPrompt;
@property (nonatomic, assign) float remindPeriod;

@property (nonatomic, copy) NSString *messageTitle;
@property (nonatomic, copy) NSString *message;
@property (nonatomic, copy) NSString *cancelButtonLabel;
@property (nonatomic, copy) NSString *remindButtonLabel;
@property (nonatomic, copy) NSString *rateButtonLabel;

@property (nonatomic, assign) BOOL useSKStoreReviewControllerIfAvailable;
@property (nonatomic, assign) BOOL useUIAlertControllerIfAvailable;
@property (nonatomic, assign) BOOL useAllAvailableLanguages;
@property (nonatomic, assign) BOOL promptForNewVersionIfUserRated;
@property (nonatomic, assign) BOOL onlyPromptIfLatestVersion;
@property (nonatomic, assign) BOOL onlyPromptIfMainWindowIsAvailable;
@property (nonatomic, assign) BOOL promptAtLaunch;
@property (nonatomic, assign) BOOL verboseLogging;
@property (nonatomic, assign) BOOL previewMode;

@property (nonatomic, strong) NSURL *ratingsURL;
@property (nonatomic, strong) NSDate *firstUsed;
@property (nonatomic, strong) NSDate *lastReminded;
@property (nonatomic, assign) NSUInteger usesCount;
@property (nonatomic, assign) NSUInteger eventCount;
@property (nonatomic, readonly) float usesPerWeek;
@property (nonatomic, assign) BOOL declinedThisVersion;
@property (nonatomic, readonly) BOOL declinedAnyVersion;
@property (nonatomic, assign) BOOL ratedThisVersion;
@property (nonatomic, readonly) BOOL ratedAnyVersion;

+ (instancetype)sharedInstance;

- (BOOL)shouldPromptForRating;
- (void)promptForRating;
- (void)promptIfNetworkAvailable;
- (void)promptIfAllCriteriaMet;
- (void)openRatingsPageInAppStore;
- (void)logEvent:(BOOL)deferPrompt;

@end


@protocol BGRateDelegate <NSObject>
@optional

- (void)rate:(BGRate *)rate couldNotConnectToAppStore:(NSError *)error;
- (void)rateDidDetectAppUpdate:(BGRate *)rate;
- (BOOL)rateShouldPromptForRating:(BGRate *)rate;
- (void)rateDidPromptForRating:(BGRate *)rate;
- (void)rateUserDidAttemptToRateApp:(BGRate *)rate;
- (void)rateUserDidDeclineToRateApp:(BGRate *)rate;
- (void)rateUserDidRequestReminderToRateApp:(BGRate *)rate;
- (BOOL)rateShouldOpenAppStore:(BGRate *)rate;
- (void)rateDidOpenAppStore:(BGRate *)rate;

@end
