//
//  MPEqualizerViewController.m
//  MoviePlayer
//
//  Created by Dominic Rodemer on 31/03/2017.
//  Copyright © 2017 Dominic Rodemer. All rights reserved.
//

#import "MPEqualizerViewController.h"

#import <BGDataBinding/BGDataBinding.h>

@interface MPEqualizerViewController ()

- (void)updateBandSlider;

@end

@implementation MPEqualizerViewController

@synthesize player;

@synthesize ampSlider;
@synthesize band2Slider;
@synthesize band3Slider;
@synthesize band4Slider;
@synthesize band5Slider;
@synthesize band6Slider;
@synthesize band7Slider;
@synthesize band8Slider;
@synthesize band9Slider;
@synthesize band10Slider;
@synthesize profilesPopup;

- (id)initWithMediaPlayer:(VLCMediaPlayer *)aPlayer
{
    if (self = [super initWithNibName:@"MPEqualizerViewController" bundle:nil])
    {
        player = aPlayer;
        player.equalizerEnabled = YES;
    }
    
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    [self updateBandSlider];
    
    NSArray *profiles =  [player equalizerProfiles];
    for (NSString *profile in profiles)
    {
        [profilesPopup addItemWithTitle:profile];
    }
}



#pragma mark ---
#pragma mark Actions
#pragma mark ---
- (IBAction)ampSliderAction:(id)sender
{
    player.preAmplification = ampSlider.doubleValue;
}

- (IBAction)band2SliderAction:(id)sender
{
    [player setAmplification:band2Slider.doubleValue forBand:1];
}

- (IBAction)band3SliderAction:(id)sender
{
    [player setAmplification:band3Slider.doubleValue forBand:2];
}

- (IBAction)band4SliderAction:(id)sender
{
    [player setAmplification:band4Slider.doubleValue forBand:3];
}

- (IBAction)band5SliderAction:(id)sender
{
    [player setAmplification:band5Slider.doubleValue forBand:4];
}

- (IBAction)band6SliderAction:(id)sender
{
    [player setAmplification:band6Slider.doubleValue forBand:5];
}

- (IBAction)band7SliderAction:(id)sender
{
    [player setAmplification:band7Slider.doubleValue forBand:6];
}

- (IBAction)band8SliderAction:(id)sender
{
    [player setAmplification:band8Slider.doubleValue forBand:7];
}

- (IBAction)band9SliderAction:(id)sender
{
    [player setAmplification:band9Slider.doubleValue forBand:8];
}

- (IBAction)band10SliderAction:(id)sender
{
    [player setAmplification:band10Slider.doubleValue forBand:9];
}

- (IBAction)profilesPopupAction:(id)sender
{
    NSUInteger index = [profilesPopup indexOfSelectedItem];
    [player resetEqualizerFromProfile:(unsigned int)index];
    [self updateBandSlider];
}



#pragma mark ---
#pragma mark Private
#pragma mark ---
- (void)updateBandSlider
{
    ampSlider.doubleValue = player.preAmplification;
    
    unsigned numberOfBands = [player numberOfBands];
    if (numberOfBands > 0)
    {
        band2Slider.doubleValue = [player amplificationOfBand:1];
    }
    else
    {
        band2Slider.doubleValue = 0.0;
        band2Slider.enabled = NO;
    }
    
    if (numberOfBands > 1)
    {
        band3Slider.doubleValue = [player amplificationOfBand:2];
    }
    else
    {
        band3Slider.doubleValue = 0.0;
        band3Slider.enabled = NO;
    }
    
    if (numberOfBands > 2)
    {
        band4Slider.doubleValue = [player amplificationOfBand:3];
    }
    else
    {
        band4Slider.doubleValue = 0.0;
        band4Slider.enabled = NO;
    }
    
    if (numberOfBands > 3)
    {
        band5Slider.doubleValue = [player amplificationOfBand:4];
    }
    else
    {
        band5Slider.doubleValue = 0.0;
        band5Slider.enabled = NO;
    }
    
    if (numberOfBands > 4)
    {
        band6Slider.doubleValue = [player amplificationOfBand:5];
    }
    else
    {
        band6Slider.doubleValue = 0.0;
        band6Slider.enabled = NO;
    }
    
    if (numberOfBands > 5)
    {
        band7Slider.doubleValue = [player amplificationOfBand:6];
    }
    else
    {
        band7Slider.doubleValue = 0.0;
        band7Slider.enabled = NO;
    }
    
    if (numberOfBands > 6)
    {
        band8Slider.doubleValue = [player amplificationOfBand:7];
    }
    else
    {
        band8Slider.doubleValue = 0.0;
        band8Slider.enabled = NO;
    }
    
    if (numberOfBands > 7)
    {
        band9Slider.doubleValue = [player amplificationOfBand:8];
    }
    else
    {
        band9Slider.doubleValue = 0.0;
        band9Slider.enabled = NO;
    }
    
    if (numberOfBands > 8)
    {
        band10Slider.doubleValue = [player amplificationOfBand:9];
    }
    else
    {
        band10Slider.doubleValue = 0.0;
        band10Slider.enabled = NO;
    }
}

@end
