//
//  MPLicenseWindowController.m
//  MoviePlayer
//
//  Created by Dominic Rodemer on 09.10.17.
//  Copyright © 2017 Dominic Rodemer. All rights reserved.
//

#import "MPLicenseWindowController.h"

#import <BGFoundation/BGFoundation.h>
#import "MPLicense.h"

@interface MPLicenseWindowController ()

- (void)updateLicense;

@end

@implementation MPLicenseWindowController

@synthesize iconView;
@synthesize purchaseButton;
@synthesize freeTrialButton;
@synthesize stateLabel;
@synthesize stateSubtitleLabel;
@synthesize nameTextField;
@synthesize licenseCodeTextField;
@synthesize closeButton;
@synthesize registerButton;

- (id)init
{
    if (self = [super initWithWindowNibName:@"MPLicenseWindowController" owner:self])
    {
        [[NSNotificationCenter defaultCenter] addObserver:self
                                                 selector:@selector(licenseDidRegisterNotification:)
                                                     name:MPLicenseDidRegisterNotification
                                                   object:nil];
    }
    
    return self;
}

- (void)dealloc
{
    [[NSNotificationCenter defaultCenter] removeObserver:self];
}

- (void)windowDidLoad
{
    [super windowDidLoad];
    
    iconView.image = [NSApp applicationIconImage];
    
    [purchaseButton sizeToFit];
    [freeTrialButton sizeToFit];
    freeTrialButton.frame = NSMakeRect(purchaseButton.frame.origin.x + purchaseButton.frame.size.width,
                                       freeTrialButton.frame.origin.y,
                                       freeTrialButton.frame.size.width,
                                       freeTrialButton.frame.size.height);
    
    [registerButton sizeToFit];
    registerButton.frame = NSMakeRect(licenseCodeTextField.frame.origin.x + licenseCodeTextField.frame.size.width - registerButton.frame.size.width + 6.0,
                                      registerButton.frame.origin.y,
                                      registerButton.frame.size.width,
                                      registerButton.frame.size.height);
    [closeButton sizeToFit];
    closeButton.frame = NSMakeRect(registerButton.frame.origin.x - closeButton.frame.size.width,
                                   closeButton.frame.origin.y,
                                   closeButton.frame.size.width,
                                   closeButton.frame.size.height);

    [self updateLicense];
}



#pragma mark ---
#pragma mark Actions
#pragma mark ---
- (IBAction)purchaseButtonAction:(id)sender
{
    NSArray *availableLanguages = @[@"de", @"es", @"fr", @"ja", @"zh", @"ru"];
    
    NSString *currentLanguage = [[[NSLocale currentLocale] objectForKey:NSLocaleLanguageCode] lowercaseString];
    NSString *urlString = @"http://www.movie-player.net/macOS/index.php?purchase=true";
    if ([availableLanguages containsObject:currentLanguage])
    {
        urlString = [NSString stringWithFormat:@"http://www.movie-player.net/%@/macOS/index.php?purchase=true", currentLanguage];
    }

    [[NSWorkspace sharedWorkspace] openURL:[NSURL URLWithString:urlString]];
}

- (IBAction)freeTrialButtonAction:(id)sender
{
    [self close];
}

- (IBAction)closeButtonAction:(id)sender
{
    [self close];
}

- (IBAction)registerButtonAction:(id)sender
{
    BOOL registered = [[MPLicense currentLicense] registerLicenseCode:licenseCodeTextField.stringValue
                                                         registeredTo:nameTextField.stringValue];
    
    if (registered)
    {
        NSAlert *alert = [[NSAlert alloc] init];
        alert.messageText = NSLocalizedString(@"Thank you for your purchase!",
                                              @"Indicate that the user has purchased the app");
        alert.informativeText = [NSString stringWithFormat:NSLocalizedString(@"Your copy of %@ is now registered.",
                                                                             @"The placeholder (%@) is the app name"), [[BGApplicationInformation defaultInformation] name]];
        [alert beginSheetModalForWindow:self.window completionHandler:^(NSModalResponse returnCode) {
            [self close];
        }];
    }
    else
    {
        NSAlert *alert = [[NSAlert alloc] init];
        alert.alertStyle = NSWarningAlertStyle;
        alert.messageText = NSLocalizedString(@"Something went wrong!",
                                              @"Indicate that an error occured");
        alert.informativeText = NSLocalizedString(@"Please check your license key and name.",
                                                  @"Promt user to check the entered license information");
        [alert beginSheetModalForWindow:self.window completionHandler:nil];
    }
}



#pragma mark ---
#pragma mark Private
#pragma mark ---
- (void)updateLicense
{
    if ([[MPLicense currentLicense] isRegistered])
    {
        stateLabel.stringValue = [NSString stringWithFormat:NSLocalizedString(@"Your copy of %@ is registered.",
                                                                              @"The placeholder (%@) is the app name"), [[BGApplicationInformation defaultInformation] name]];
        stateSubtitleLabel.stringValue = NSLocalizedString(@"Thank you for your support!",
                                                           @"Message after a succesfull purchase of the app");
        purchaseButton.hidden = YES;
        freeTrialButton.hidden = YES;
        
        nameTextField.stringValue = [[MPLicense currentLicense] registeredLicenseName];
        licenseCodeTextField.stringValue = [[MPLicense currentLicense] registeredLicenseCode];
        closeButton.hidden = NO;
    }
    else if ([[MPLicense currentLicense] isTrialPeriod])
    {
        stateLabel.stringValue = [NSString stringWithFormat:NSLocalizedString(@"Your copy of %@ is not registered yet!",
                                                                              @"The placeholder (%@) is the app name"), [[BGApplicationInformation defaultInformation] name]];
        stateSubtitleLabel.stringValue = [NSString stringWithFormat:NSLocalizedString(@"You have %d days left in your free trial period.",
                                                                                      @"Indicate the numbers of days left for the demo"), [[MPLicense currentLicense] remainingDaysInTrialPeriod]];
        freeTrialButton.hidden = NO;
        closeButton.hidden = YES;
    }
    else
    {
        stateLabel.stringValue = [NSString stringWithFormat:NSLocalizedString(@"Your copy of %@ is not registered yet!",
                                                                              @"The placeholder (%@) is the app name"), [[BGApplicationInformation defaultInformation] name]];
        stateSubtitleLabel.stringValue = NSLocalizedString(@"Your free trial period has been expired.",
                                                           @"Indicate that the free trial periaod of the app has been expired");
        freeTrialButton.hidden = YES;
        closeButton.hidden = YES;
    }
    
    registerButton.enabled = NO; //Will be enabled if one of the text fields changes
}



#pragma mark ---
#pragma mark NSTextFieldDelegate
#pragma mark ---
- (void)controlTextDidChange:(NSNotification *)notification
{
    registerButton.enabled = [nameTextField.stringValue length] > 0 && [licenseCodeTextField.stringValue length] > 0;
}



#pragma mark ---
#pragma mark MPLicense Notifications
#pragma mark ---
- (void)licenseDidRegisterNotification:(NSNotification *)notification
{
    [self updateLicense];
}

@end
