//
//  MPMainMenu.m
//  MoviePlayer
//
//  Created by Dominic Rodemer on 08.04.17.
//  Copyright © 2017 Dominic Rodemer. All rights reserved.
//

#import "MPMainMenu.h"


@interface MPMainMenu ()

- (void)setControlsEnabled:(BOOL)enabled ofView:(NSView *)view;

@end


@implementation MPMainMenu

@synthesize audioMenu;
@synthesize audioTrackMenu;

@synthesize videoMenu;
@synthesize videoTrackMenu;

@synthesize subtitlesMenu;
@synthesize addSubtitleFileItem;
@synthesize subtitlesTrackMenu;
@synthesize subtitlesDelayView;
@synthesize subtitlesDelaySlider;

+ (MPMainMenu *)mainMenu
{
    __strong static MPMainMenu *mainMenu = nil;
    static dispatch_once_t onceToken;
    dispatch_once(&onceToken, ^{
        mainMenu = [[MPMainMenu _alloc] _init];
    });
    
    return mainMenu;
}



#pragma mark ---
#pragma mark Interface Builder Singleton Compatibility
#pragma mark ---
+ (id)allocWithZone:(NSZone *)zone
{
    return [self mainMenu];
}

+ (id)alloc
{
    return [self mainMenu];
}

- (id)init
{
    return self;
}

+ (id)_alloc
{
    return [super allocWithZone:NULL];
}

- (id)_init
{
    return [super init];
}



#pragma mark ---
#pragma mark Accessors
#pragma mark ---
- (BOOL)subtitlesDelayViewEnabled
{
    return subtitlesDelayViewEnabled;
}

- (void)setSubtitlesDelayViewEnabled:(BOOL)isSubtitlesDelayViewEnabled
{
    subtitlesDelayViewEnabled = isSubtitlesDelayViewEnabled;
    [self setControlsEnabled:subtitlesDelayViewEnabled ofView:subtitlesDelayView];
}



#pragma mark ---
#pragma mark Private
#pragma mark ---
- (void)setControlsEnabled:(BOOL)enabled ofView:(NSView *)view
{
    NSView *currentView = NULL;
    NSEnumerator *viewEnumerator = [[view subviews] objectEnumerator];
    while(currentView = [viewEnumerator nextObject])
    {
        if ([currentView isKindOfClass:[NSControl class]])
        {
            [(NSControl *)currentView setEnabled:enabled];
        }
        if ([currentView isKindOfClass:[NSTextField class]])
        {
            if (enabled)
                [(NSTextField *)currentView setTextColor:[NSColor controlTextColor]];
            else
                [(NSTextField *)currentView setTextColor:[NSColor disabledControlTextColor]];
        }
        
        [self setControlsEnabled:enabled ofView:currentView];
        [currentView display];
    }
}

@end
