//
//  MPMediaParser.m
//  MoviePlayer
//
//  Created by Dominic Rodemer on 28/03/2017.
//  Copyright © 2017 Dominic Rodemer. All rights reserved.
//

#import "MPMediaParser.h"

NSString *const MPMediaParserDidParseMediaNotification = @"MPMediaParserDidParseMediaNotification";
NSString *const MPMediaParsereMediaKey = @"MPMediaParsereMediaKey";

@implementation MPMediaParser

- (id)init
{
    if (self = [super init])
    {
        mediaItems = [[NSMutableSet alloc] init];
    }
    
    return self;
}

+ (MPMediaParser *)sharedParser
{
    static MPMediaParser *sharedParser = nil;
    static dispatch_once_t onceToken;
    dispatch_once(&onceToken, ^{
        sharedParser = [[MPMediaParser alloc] init];
    });
    
    return sharedParser;
}



#pragma mark ---
#pragma mark Public
#pragma mark ---
- (void)parseMedia:(VLCMedia *)media
{
    if (!media)
        return;
    
    if (media.parsedStatus == VLCMediaParsedStatusDone)
        return;
    
    [mediaItems addObject:media];
    media.delegate = self;
    [media parseWithOptions:VLCMediaParseLocal | VLCMediaParseNetwork timeout:10000]; //wait 10 seconds
}


#pragma mark ---
#pragma mark VLCMediaDelegate
#pragma mark ---
- (void)mediaDidFinishParsing:(VLCMedia *)media
{
    media.delegate = nil;
    [mediaItems removeObject:media];
    
    if (media.parsedStatus == VLCMediaParsedStatusDone)
    {
        [[NSNotificationCenter defaultCenter] postNotificationName:MPMediaParserDidParseMediaNotification
                                                            object:self
                                                          userInfo:@{MPMediaParsereMediaKey : media}];
    }
}

@end
