//
//  MPPlayerControlView.m
//  MoviePlayer
//
//  Created by Dominic Rodemer on 23/03/2017.
//  Copyright © 2017 Dominic Rodemer. All rights reserved.
//

#import "MPPlayerControlView.h"

@implementation MPPlayerControlView

@synthesize visible;

@synthesize playButton;
@synthesize nextButton;
@synthesize jumpForwardButton;
@synthesize previousButton;
@synthesize jumpBackwardButton;
@synthesize volumeSlider;
@synthesize volumeUpButton;
@synthesize volumeDownButton;
@synthesize equalizerButton;
@synthesize videoAdjustmentsButton;
@synthesize playlistButton;
@synthesize timeSlider;
@synthesize currentTimeLabel;
@synthesize timeLeftLabel;

- (void)setupMPPlayerControlView
{
    visible = YES;
}

- (id)initWithFrame:(NSRect)frameRect
{
    if (self = [super initWithFrame:frameRect])
    {
        [self setupMPPlayerControlView];
    }
    
    return self;
}

- (id)initWithCoder:(NSCoder *)coder
{
    if (self = [super initWithCoder:coder])
    {
        [self setupMPPlayerControlView];
    }
    
    return self;
}

#pragma mark ---
#pragma mark Public
#pragma mark ---
- (void)showAnimated:(BOOL)animated
{
    if (visible)
        return;
    
    self.hidden = NO;
    
    [NSAnimationContext runAnimationGroup:^(NSAnimationContext *context) {
        
        if (!animated)
            [context setDuration:0];
        self.animator.alphaValue = 1.0;
    } completionHandler:^{
        
        self->visible = YES;
    }];
}

- (void)hideAnimated:(BOOL)animated
{
    if (!visible)
        return;
    
    [NSAnimationContext runAnimationGroup:^(NSAnimationContext *context) {
        
        if (!animated)
            [context setDuration:0];
        self.animator.alphaValue = 0.0;
    } completionHandler:^{
        
        self->visible = NO;
        self.hidden = YES;
    }];
}

- (void)enableTimeSlider
{
    timeSlider.enabled = YES;
    currentTimeLabel.hidden = NO;
    timeLeftLabel.hidden = NO;
}

- (void)disableTimeSlider
{
    timeSlider.enabled = NO;
    currentTimeLabel.hidden = YES;
    timeLeftLabel.hidden = YES;
}

- (void)updateTimeSliderWithCurrentTime:(VLCTime *)currentTime remainingTime:(VLCTime *)remainingTime
{
    if (currentTime)
        currentTimeLabel.stringValue = [currentTime stringValue];
    else
        currentTimeLabel.stringValue = @"00:00:00";
    
    if (remainingTime)
        timeLeftLabel.stringValue = [NSString stringWithFormat:@"%@", [remainingTime stringValue]];
    else
        timeLeftLabel.stringValue = @"";
    
    if ((int)timeSlider.maxValue > 0)
        timeSlider.intValue = [currentTime intValue];
    else
        timeSlider.intValue = 0;
}

@end
