//
//  MPPlayerWindow.m
//  MoviePlayer
//
//  Created by Dominic Rodemer on 22/03/2017.
//  Copyright © 2017 Dominic Rodemer. All rights reserved.
//

#import "MPPlayerWindow.h"

@implementation MPPlayerWindow

@synthesize titleBarView;
@synthesize titleBarVisible;

- (id)initWithContentRect:(NSRect)contentRect styleMask:(NSWindowStyleMask)style backing:(NSBackingStoreType)bufferingType defer:(BOOL)flag
{
    if (self = [super initWithContentRect:contentRect styleMask:style backing:bufferingType defer:flag])
    {
        id potentialTitleBarView = [[self standardWindowButton:NSWindowCloseButton] superview];
        if ([potentialTitleBarView isKindOfClass:[NSVisualEffectView class]])
        {
            titleBarView = potentialTitleBarView;
        }
        
        for (id potentialTitleBarContainerView in self.contentView.superview.subviews)
        {
            if ([potentialTitleBarContainerView isKindOfClass:NSClassFromString(@"NSTitlebarContainerView")])
            {
                titleBarContainerView = potentialTitleBarContainerView;
                break;
            }
        }
        
        [self.contentView setWantsLayer:YES];
        self.styleMask |= NSFullSizeContentViewWindowMask;
        self.movableByWindowBackground = YES;
                
        titleBarVisible = YES;
    }
    
    return self;
}

- (void)makeKeyAndOrderFront:(id)sender
{
    [super makeKeyAndOrderFront:sender];
    

}



#pragma mark ---
#pragma mark Public
#pragma mark ---
- (void)showTitleBarAnimated:(BOOL)animated
{
    if (titleBarVisible)
        return;
    
    titleBarView.hidden = NO;
    
    [NSAnimationContext runAnimationGroup:^(NSAnimationContext *context) {
        
        if (!animated)
            [context setDuration:0];
        self->titleBarContainerView.animator.alphaValue = 1;
    } completionHandler:^{
        
        self->titleBarVisible = YES;
    }];
}

- (void)hideTitleBarAnimated:(BOOL)animated
{
    if (!titleBarVisible)
        return;
    
    // do not hide titlebar when in fullscreen mode
    if ((self.styleMask & NSFullScreenWindowMask))
        return;
    
    [NSAnimationContext runAnimationGroup:^(NSAnimationContext *context) {
        
        if (!animated)
            [context setDuration:0];
        self->titleBarContainerView.animator.alphaValue = 0;
    } completionHandler:^{
        
        self->titleBarVisible = NO;
        self->titleBarView.hidden = YES;
    }];
}

- (void)sizeToFitVideoSize:(NSSize)videoSize aspectRatio:(NSSize)aspectRatio animated:(BOOL)animate
{
    if (!(self.styleMask & NSFullScreenWindowMask)) //Do not resize in fullscreen mode
    {
        NSSize contrainedSize = videoSize;
        if (contrainedSize.width < self.minSize.width)
        {
            contrainedSize = NSMakeSize(self.minSize.width,
                                        contrainedSize.height * self.minSize.width/contrainedSize.width);
        }
        if (contrainedSize.height < self.minSize.height)
        {
            contrainedSize = NSMakeSize(contrainedSize.width * self.minSize.height/contrainedSize.height,
                                        self.minSize.height);
        }
        if (contrainedSize.width > self.maxSize.width)
        {
            contrainedSize = NSMakeSize(self.maxSize.width,
                                        contrainedSize.height * self.maxSize.width/contrainedSize.width);
        }
        if (contrainedSize.height > self.maxSize.height)
        {
            contrainedSize = NSMakeSize(contrainedSize.width * self.maxSize.height/contrainedSize.height,
                                        self.maxSize.height);
        }
        NSRect frame = [self frame];
        frame.size = contrainedSize;
        [self setFrame:frame display:YES animate:animate];
    }
    
    [self setAspectRatio:aspectRatio];
    [self setContentAspectRatio:aspectRatio];
}

@end
