//
//  MPSidePanelViewController.m
//  MoviePlayer
//
//  Created by Dominic Rodemer on 27/03/2017.
//  Copyright © 2017 Dominic Rodemer. All rights reserved.
//

#import "MPSidePanelViewController.h"

@interface MPSidePanelViewController ()

@property (nonatomic) BOOL visible;

@end


@implementation MPSidePanelViewController

@synthesize delegate;
@synthesize visible;
@synthesize visibleFromEdge;

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    if (self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil])
    {
        visible = YES;
    }
    
    return self;
}



#pragma mark ---
#pragma mark MPSidePanelViewControllerSubclassingHooks
#pragma mark ---
- (void)sidePanelDidShow
{
    /*
     * Abstract method
     */
}



#pragma mark ---
#pragma mark Public
#pragma mark ---
- (void)showFromEdge:(MPSidePanelViewControllerEdge)edge animated:(BOOL)animated
{
    if (visible)
        return;
    self.visible = YES;
    
    CGRect fromFrame = CGRectZero;
    CGRect toFrame = CGRectZero;
    if (edge == MPSidePanelViewControllerEdgeRight)
    {
        fromFrame = CGRectMake(self.view.superview.frame.size.width,
                               0.0,
                               self.view.frame.size.width,
                               self.view.superview.frame.size.height);
        toFrame = CGRectMake(self.view.superview.frame.size.width - self.view.frame.size.width,
                             0.0,
                             self.view.frame.size.width,
                             self.view.superview.frame.size.height);
        self.view.autoresizingMask = NSViewHeightSizable | NSViewMinXMargin;
    }
    else if (edge == MPSidePanelViewControllerEdgeLeft)
    {
        fromFrame = CGRectMake(-self.view.frame.size.width,
                               0.0,
                               self.view.frame.size.width,
                               self.view.superview.frame.size.height);
        toFrame = CGRectMake(0.0,
                             0.0,
                             self.view.frame.size.width,
                             self.view.superview.frame.size.height);
        self.view.autoresizingMask = NSViewHeightSizable | NSViewMaxXMargin;
    }
    else if (edge == MPSidePanelViewControllerEdgeTop)
    {
        fromFrame = CGRectMake(0.0,
                               self.view.superview.frame.size.height,
                               self.view.superview.frame.size.width,
                               self.view.frame.size.height);
        toFrame = CGRectMake(0.0,
                             self.view.superview.frame.size.height - self.view.frame.size.height,
                             self.view.superview.frame.size.width,
                             self.view.frame.size.height);
        self.view.autoresizingMask = NSViewWidthSizable | NSViewMinYMargin;
    }
    else if (edge == MPSidePanelViewControllerEdgeBottom)
    {
        fromFrame = CGRectMake(0.0,
                               -self.view.frame.size.height,
                               self.view.superview.frame.size.width,
                               self.view.frame.size.height);
        toFrame = CGRectMake(0.0,
                             0.0,
                             self.view.superview.frame.size.width,
                             self.view.frame.size.height);
        self.view.autoresizingMask = NSViewWidthSizable | NSViewMaxYMargin;
    }
    
    visibleFromEdge = edge;
    
    if ([delegate respondsToSelector:@selector(sidePanelViewControllerWillShow:animated:)])
    {
        [delegate sidePanelViewControllerWillShow:self animated:animated];
    }
    
    if (animated)
    {
        self.view.frame = fromFrame;
        self.view.hidden = NO;
        
        [NSAnimationContext runAnimationGroup:^(NSAnimationContext *context) {
            self.view.animator.frame = toFrame;
        } completionHandler:^{
            [self sidePanelDidShow];
            if ([self->delegate respondsToSelector:@selector(sidePanelViewControllerDidShow:animated:)])
            {
                [self->delegate sidePanelViewControllerDidShow:self animated:YES];
            }
        }];
    }
    else
    {
        self.view.frame = toFrame;
        self.view.hidden = NO;
        [self sidePanelDidShow];
        if ([delegate respondsToSelector:@selector(sidePanelViewControllerDidShow:animated:)])
        {
            [delegate sidePanelViewControllerDidShow:self animated:NO];
        }
    }
}

- (void)hideToEdge:(MPSidePanelViewControllerEdge)edge animated:(BOOL)animated
{
    if (!visible)
        return;
    
    CGRect toFrame = CGRectZero;
    if (edge == MPSidePanelViewControllerEdgeRight)
    {
        toFrame = CGRectMake(self.view.superview.frame.size.width,
                             0.0,
                             self.view.frame.size.width,
                             self.view.frame.size.height);
        self.view.autoresizingMask = NSViewHeightSizable | NSViewMinXMargin;
    }
    else if (edge == MPSidePanelViewControllerEdgeLeft)
    {
        toFrame = CGRectMake(-self.view.frame.size.width,
                             0.0,
                             self.view.frame.size.width,
                             self.view.frame.size.height);
        self.view.autoresizingMask = NSViewHeightSizable | NSViewMaxXMargin;
    }
    else if (edge == MPSidePanelViewControllerEdgeTop)
    {
        toFrame = CGRectMake(0.0,
                             self.view.superview.frame.size.height,
                             self.view.frame.size.width,
                             self.view.frame.size.height);
        self.view.autoresizingMask = NSViewWidthSizable | NSViewMinYMargin;
    }
    else if (edge == MPSidePanelViewControllerEdgeBottom)
    {
        toFrame = CGRectMake(0.0,
                             -self.view.frame.size.height,
                             self.view.frame.size.width,
                             self.view.frame.size.height);
        self.view.autoresizingMask = NSViewWidthSizable | NSViewMaxYMargin;
    }

    if ([delegate respondsToSelector:@selector(sidePanelViewControllerWillHide:animated:)])
    {
        [delegate sidePanelViewControllerWillHide:self animated:animated];
    }
    
    if (animated)
    {
        [NSAnimationContext runAnimationGroup:^(NSAnimationContext *context) {
            self.view.animator.frame = toFrame;
        } completionHandler:^{
            self.view.hidden = NO;
            self.visible = NO;
        }];
    }
    else
    {
        self.view.frame = toFrame;
        self.view.hidden = YES;
        self.visible = NO;
    }
}

@end
