//
//  MPTimeSliderCell.m
//  MoviePlayer
//
//  Created by Dominic Rodemer on 23/03/2017.
//  Copyright © 2017 Dominic Rodemer. All rights reserved.
//

#import "MPTimeSliderCell.h"

CGFloat const MPTimeSliderKnobWidth = 4;
CGFloat const MPTimeSliderKnobRadius = 1.0;

@implementation MPTimeSliderCell

- (void)drawKnob:(NSRect)knobRect
{
    NSRect alignedKnobRect = knobRect;
    alignedKnobRect.origin.x += 1;
    alignedKnobRect.size.width -= 1;
    
    NSBezierPath *knob = [NSBezierPath  bezierPathWithRoundedRect:alignedKnobRect
                                                          xRadius:MPTimeSliderKnobRadius
                                                          yRadius:MPTimeSliderKnobRadius];
    [[NSColor secondaryLabelColor] setFill];
    [knob fill];
    
    NSRect leftSpacerRect = NSMakeRect(knobRect.origin.x,
                                       knobRect.origin.y,
                                       1.0,
                                       NSHeight(knobRect));
    [[NSColor blackColor] setFill];
    NSRectFill(leftSpacerRect);
    
    NSRect rightSpacerRect = NSMakeRect(knobRect.origin.x+NSWidth(knobRect),
                                        knobRect.origin.y,
                                        1.0,
                                        NSHeight(knobRect));
    [[NSColor blackColor] setFill];
    NSRectFill(rightSpacerRect);
}


- (NSRect)knobRectFlipped:(BOOL)flipped
{
    CGFloat value = (self.doubleValue - self.minValue) / (self.maxValue - self.minValue);
    
    NSRect defaultKnobRect = [super knobRectFlipped:flipped];
    NSRect actualKnobRect = NSMakeRect(0, 0, 0, 0);
    
    actualKnobRect.size.width = MPTimeSliderKnobWidth;
    actualKnobRect.size.height = self.controlView.frame.size.height - 2.0;
    actualKnobRect.origin.x = round(value * (self.controlView.frame.size.width - MPTimeSliderKnobWidth));
    actualKnobRect.origin.y = round(NSHeight(defaultKnobRect)/2 - NSHeight(actualKnobRect)/2) - 1.0;
    
    return actualKnobRect;
}

@end
