//
//  MPTrackingView.m
//  MoviePlayer
//
//  Created by Dominic Rodemer on 22/03/2017.
//  Copyright © 2017 Dominic Rodemer. All rights reserved.
//

#import "MPTrackingView.h"

@implementation MPTrackingView

@synthesize trackingArea;

@synthesize mouseEnteredHandler;
@synthesize mouseExitedHandler;
@synthesize mouseMovedHandler;

@synthesize trackingEnabled;

- (id)initWithFrame:(NSRect)frame
{
    if (self = [super initWithFrame:frame])
    {
        trackingEnabled = YES;
        
        trackingArea = [[NSTrackingArea alloc] initWithRect:self.bounds
                                                    options:(NSTrackingMouseEnteredAndExited | NSTrackingMouseMoved | NSTrackingActiveInKeyWindow )
                                                      owner:self
                                                   userInfo:nil];
        [self addTrackingArea:trackingArea];
    }
    
    return self;
}

- (void)updateTrackingAreas
{
    [self removeTrackingArea:trackingArea];
    trackingArea = [[NSTrackingArea alloc] initWithRect:self.bounds
                                                options:(NSTrackingMouseEnteredAndExited | NSTrackingMouseMoved | NSTrackingActiveInKeyWindow )
                                                  owner:self
                                               userInfo:nil];
    [self addTrackingArea:trackingArea];
}



#pragma mark ---
#pragma mark NSResponder
#pragma mark ---
- (void)mouseEntered:(NSEvent *)event
{
    [super mouseEntered:event];
    
    if (!trackingEnabled)
        return;
    
    if (mouseEnteredHandler)
        mouseEnteredHandler();
}

- (void)mouseExited:(NSEvent *)event
{
    [super mouseExited:event];
    
    if (!trackingEnabled)
        return;
    
    if (mouseExitedHandler)
        mouseExitedHandler();
}

- (void)mouseMoved:(NSEvent *)theEvent
{
    [super mouseMoved:theEvent];
    
    if (!trackingEnabled)
        return;
    
    if (mouseMovedHandler)
        mouseMovedHandler();
}

@end
