//
//  MPVideoContainerView.m
//  MoviePlayer
//
//  Created by Dominic Rodemer on 24/03/2017.
//  Copyright © 2017 Dominic Rodemer. All rights reserved.
//

#import "MPVideoContainerView.h"

@interface MPVideoContainerView ()

- (void)layoutVideoView;

@end

@implementation MPVideoContainerView

@synthesize videoView;

- (void)drawRect:(NSRect)dirtyRect
{
    [super drawRect:dirtyRect];
    
    [[NSColor blackColor] setFill];
    NSRectFill(dirtyRect);
}

- (void)resizeSubviewsWithOldSize:(NSSize)oldSize
{
    [super resizeSubviewsWithOldSize:oldSize];
    
    [self layoutVideoView];
}



#pragma mark ---
#pragma mark Accessors
#pragma mark ---
- (CGSize)videoSize
{
    return videoSize;
}

- (void)setVideoSize:(CGSize)aVideoSize
{
    videoSize = aVideoSize;
    [self layoutVideoView];
}



#pragma mark ---
#pragma mark Private
#pragma mark ---
- (void)layoutVideoView
{
    CGFloat videoWidth = self.frame.size.width;
    CGFloat videoHeight = self.frame.size.height;
    if (videoSize.width > 0 && videoSize.height > 0)
    {
        CGFloat horizontalScale = self.frame.size.width/videoSize.width;
        CGFloat verticalScale = self.frame.size.height/videoSize.height;
        
        if (verticalScale > horizontalScale)
        {
            videoHeight = videoSize.height * horizontalScale;
        }
        else if (horizontalScale > verticalScale)
        {
            videoWidth = videoSize.width * verticalScale;
        }
    }
    
    videoView.frame = NSMakeRect(floorf(self.frame.size.width/2 - videoWidth/2) - 1.0,
                                 floorf(self.frame.size.height/2 - videoHeight/2) - 1.0,
                                 videoWidth + 2.0,
                                 videoHeight + 2.0);
}

@end
