//
//  VLCMedia+MoviePlayer.m
//  MoviePlayer
//
//  Created by Dominic Rodemer on 28/03/2017.
//  Copyright © 2017 Dominic Rodemer. All rights reserved.
//

#import "VLCMedia+MoviePlayer.h"

#import <BGFoundation/BGFoundation.h>

@implementation VLCMedia (MoviePlayer)

- (NSString *)mp_filePath
{
    return [[self.url path] bg_URLDecodedString];
}


- (NSString *)mp_correspondingSubtitleFilePathInMediaDirectory
{
    NSArray *subtitleFileExtensions = [VLCMedia mp_supportedSubtitleFileTypes];
    NSString *filePathWithoutExtension = [[self mp_filePath] stringByDeletingPathExtension];
    
    for (NSString *extension in subtitleFileExtensions)
    {
        NSString *subtitleFilePath = [filePathWithoutExtension stringByAppendingPathExtension:extension];
        if ([[NSFileManager defaultManager] fileExistsAtPath:subtitleFilePath])
        {
            if ([[NSFileManager defaultManager] isReadableFileAtPath:subtitleFilePath])
            {
                return subtitleFilePath;
            }
        }
    }
    
    return nil;
}

- (NSString *)mp_title
{
    NSString *fileName = [[self mp_filePath] lastPathComponent];
    if (fileName)
        return [fileName stringByDeletingPathExtension];
    
    return @"No name";
}

- (NSImage *)mp_fileIcon
{
    static NSDictionary *fileImages = nil;
    static dispatch_once_t onceToken;
    dispatch_once(&onceToken, ^{
        
        NSMutableDictionary *tmpFileImages = [NSMutableDictionary dictionary];
        NSArray *documentTypes = [[[NSBundle mainBundle] infoDictionary] objectForKey:@"CFBundleDocumentTypes"];
        for (NSDictionary *documentType in documentTypes)
        {
            NSString *imageName = [[documentType objectForKey:@"CFBundleTypeIconFile"] stringByDeletingPathExtension];
            if (!imageName)
                continue;
            
            NSArray *extensions = [documentType objectForKey:@"CFBundleTypeExtensions"];
            for (NSString *extension in extensions)
            {
                [tmpFileImages setObject:imageName forKey:[extension lowercaseString]];
            }
        }
        
        fileImages = [NSDictionary dictionaryWithDictionary:tmpFileImages];
    });
    
    NSString *fileExtension = [[self mp_filePath] pathExtension];
    if (fileExtension)
    {
        NSString *imageName = [fileImages objectForKey:[fileExtension lowercaseString]];
        if (imageName)
        {
            NSImage *image = [NSImage imageNamed:imageName];
            if (image)
                return image;
        }
    }
    
    return [NSImage imageNamed:@"Generic"];
}

+ (NSArray *)mp_supportedFileTypes
{
    static NSArray *fileTypes = nil;
    static dispatch_once_t onceToken;
    dispatch_once(&onceToken, ^{
        
        NSMutableArray *tmpFileTypes = [NSMutableArray array];
        NSArray *documentTypes = [[[NSBundle mainBundle] infoDictionary] objectForKey:@"CFBundleDocumentTypes"];
        for (NSDictionary *documentType in documentTypes)
        {
            NSArray *extensions = [documentType objectForKey:@"CFBundleTypeExtensions"];
            for (NSString *extension in extensions)
            {
                NSString *lowecaseExtension = [extension lowercaseString];
                if (![tmpFileTypes containsObject:lowecaseExtension])
                    [tmpFileTypes addObject:lowecaseExtension];
            }
        }
        
        fileTypes = [NSArray arrayWithArray:tmpFileTypes];
    });
    
    return fileTypes;
}

+ (NSArray *)mp_supportedSubtitleFileTypes
{
    static NSArray *fileTypes = nil;
    static dispatch_once_t onceToken;
    dispatch_once(&onceToken, ^{
        fileTypes = @[@"cdg", @"idx", @"srt", @"sub", @"utf", @"ass", @"ssa", @"aqt", @"jss", @"psb", @"rt", @"smi", @"txt", @"smil"];
    });
    
    return fileTypes;
}

+ (NSArray *)mp_supportedMediaFileTypes
{
    static NSArray *fileTypes = nil;
    static dispatch_once_t onceToken;
    dispatch_once(&onceToken, ^{
        NSMutableArray *tmpFileTypes = [NSMutableArray arrayWithArray:[VLCMedia mp_supportedFileTypes]];
        [tmpFileTypes removeObjectsInArray:[VLCMedia mp_supportedSubtitleFileTypes]];
        fileTypes = [NSArray arrayWithArray:tmpFileTypes];
    });
    
    return fileTypes;
}

@end
